:
#
# Copyright (c) 2004 by James A. McQuillan (McQuillan Systems)
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# MCQUILLAN SYSTEMS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
# OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# 04/06/2004 -Jim McQuillan- Added the cx5530 driver for sound on J-125
#
# 04/03/2004 -Jim McQuillan- Custom kernel specifically for via c3 chips
#
# 04/01/2004 -Jim McQuillan- Removed the trident fb driver, it caused lots
#                            of problems on trident video cards.
#
# 02/04/2004 -Jim McQuillan- Upgraded to 2.4.24 kernel
#                            Added support for nvidia network cards
#                            Added support in /linuxrc to pass static
#                              addresses via the kernel command line
#                            Added supermount patch
#
# 09/23/2003 -Jim McQuillan- Upgraded to 2.4.22 kernel
#                            Added support for PXE booting
#                            Removed LPP temporarily, as we try to find
#                            a LPP patch for 2.4.22.
#
# 07/05/2003 -Jim McQuillan- added LPP
#
# 06/30/2003 -Jim McQuillan- Upgraded to 2.4.21 kernel
#
# 04/18/2003 -Jim McQuillan- Changed the DPORT option to specify the
#                            lower number (67) rather than (68).
#
# 04/11/2003 -Jim McQuillan- Added sundance NIC driver, and added DPORT=xx
#                            kernel cmdline arg, to be passed to /linuxrc
#                            to control the udp port that dhclient uses.
#
# 09/04/2002 -Jim McQuillan- Updated to version 2.4.19 of the Linux kernel
#                            Added cx5530 sound driver module to support
#                            sound on the Jammin-125 workstation.
#                            Added PCI ids for natsemi cards
#
# 06/19/2002 -Jim McQuillan- Updated to version 2.4.18 of the Linux kernel
#
# 03/11/2002 -Jim McQuillan- Changed the linuxrc script to use modprobe instead
#                            of insmod so that the 8390 module would always get
#                            loaded when needed.
#
# 12/11/2001 -Jim McQuillan- Added loading of 8390 when NIC = e2100, smc-ultra
#                            and wd.
#
# 12/02/2001 -Jim McQuillan- Updated for LTSP 3.0.0
#
# 10/28/2001 -Jim McQuillan- Now includes 2 kernels, one with the LPP
#                            patch, the other without.
#
# 09/26/2001 -Jim McQuillan- Updated for LTSP 2.09pre2
#
##############################################################################

##############################################################################
#
# Make sure this script is being run by the superuser.
#
if [ "${LOGNAME}" != "root" ]; then
    echo
    echo "You MUST run this script as superuser!"
    echo
    echo "If you logged in as a normal user then su'ed to become"
    echo "superuser, you also need to add a hyphen '-' to the"
    echo "su command".
    echo
    exit 1
fi


if [ ! -f /etc/ltsp.conf ]; then
    echo
    echo "Couldn't find /etc/ltsp.conf, probably indicates that"
    echo "lts_core hasn't been installed yet"
    echo
    exit 1
fi

. /etc/ltsp.conf

if [ ! -d ${LTSP_DIR} ]; then
    echo
    echo "Could not find ${LTSP_DIR}"
    echo "Has it moved, without updating /etc/ltsp.conf ?"
    echo
    exit 1
fi

if [ ! -d /tftpboot/lts ]; then
    mkdir -p /tftpboot/lts
fi

#
# Setup the Etherboot kernel
#
VERSION=2.4.24-ltsp-4
EB_KERNEL=vmlinuz-${VERSION}

cp ${EB_KERNEL}     /tftpboot/lts/${EB_KERNEL}
chmod 444 /tftpboot/lts/${EB_KERNEL}

#
# Setup the PXE kernel
#
PXEDIR=/tftpboot/lts/${VERSION}

if [ ! -d ${PXEDIR} ]; then
    mkdir ${PXEDIR}
fi

mv pxelinux.0 ${PXEDIR}

if [ ! -d ${PXEDIR}/pxelinux.cfg ]; then
    mkdir ${PXEDIR}/pxelinux.cfg
fi


cat <<EOF >${PXEDIR}/pxelinux.cfg/default
prompt=0
label linux
	kernel bzImage-${VERSION}
        append init=/linuxrc rw root=/dev/ram0 initrd=initrd-${VERSION}.gz 
EOF

mv README.pxe  ${PXEDIR}

#
# Now, the tricky stuff.  We'll extract the kernel and initrd from the tagged
# Etherboot kernel.  This way, we don't have to ship both a tagged and a
# non-tagged kernel in the tarball.
#
echo
echo "Extracting un-tagged kernel"

#
# The following variable needs to be changed when using
# a different kernel
#
KERNEL_LEN=876394

KERNEL_OFFSET_BLOCKS=11
KERNEL_BLOCKS=`expr ${KERNEL_LEN} / 512`
KERNEL_REMAINDER=`expr ${KERNEL_LEN} % 512`
if [ ${KERNEL_REMAINDER} -gt 0 ]; then
  KERNEL_BLOCKS=`expr ${KERNEL_BLOCKS} + 1`
fi
INITRD_OFFSET_BLOCKS=`expr ${KERNEL_OFFSET_BLOCKS} + ${KERNEL_BLOCKS}`

dd if=/tftpboot/lts/${EB_KERNEL}	\
   bs=512				\
   skip=${KERNEL_OFFSET_BLOCKS}		\
   count=${KERNEL_BLOCKS}		\
   of=${PXEDIR}/bzImage-${VERSION}

echo
echo "Extracting un-tagged initrd"
dd if=/tftpboot/lts/${EB_KERNEL}	\
   bs=512				\
   skip=${INITRD_OFFSET_BLOCKS}		\
   of=${PXEDIR}/initrd-${VERSION}.gz

#
# Copy the kernel modules
#
echo "Installing kernel modules"
find i386 -print | cpio -pmud --quiet ${LTSP_DIR}
RS=$?
if [ ${RS} -ne 0 ]; then
    echo
    echo "Copying of modules failed, errno=${RS}"
    echo
    exit 1
fi

echo
echo "If you want to use PXE, then you need to take"
echo "a look at /tftpboot/lts/${VERSION}/README.pxe"
echo
